@@ -6,9 +6,9 @@ from website_sitemap_parser.elements import Page, Sitemap
 from urllib.parse import urljoin
 
 
-def process_sitemap(sitemap: Sitemap, timeout=None, headers=None, cookies=None):
+def process_sitemap(url: str, timeout=None, headers=None, cookies=None):
     yield from xml_parser.parse(
-        sitemap.url,
+        url,
         timeout=timeout,
         headers=headers,
         cookies=cookies,
